# Google Spreadsheets
This is a super lightweight wrapper around the Google Sheets API.<br>
It allows users to easily read and write sheets to and from Pandas DataFrames.

This is made public and hosted on PyPi for selfish reasons.

By Leon Yin
